Authors
-------

DataCite is developed for use in `Invenio <http://inveniosoftware.org>`_
digital library software.

Contact us at `info@inveniosoftware.org <mailto:info@inveniosoftware.org>`_

Contributors
^^^^^^^^^^^^
* Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
* Laura Rueda Garcia <laura.rueda@cern.ch>
* Jiri Kuncar <jiri.kuncar@cern.ch>
* Sami Hiltunen <sami.mikael.hiltunen@cern.ch>
* Tibor Simko <tibor.simko@cern.ch>
* Rémi Ducceschi <remi.ducceschi@gmail.com>
